this.name			= "thargoid_weaponry_conditions";
this.author			= "Montana05";
this.description	= "conditions for the handling of Thargoid Weaponry";
this.version		= "1.20";
this.copyright		= "2021 Montana05";
this.licence   		= "CC BY-NC-SA 4.0";
"use strict";

this.allowAwardEquipment = function(equipment, ship, context)
{
	var dice = (Math.random() * 100).toFixed(0);
	var shipMass = 0;
	
	// remainder from oolite-conditions.js:

	// OXP hook to allow stations to forbid specific equipment
	if(context == "purchase" && player.ship.dockedStation && player.ship.dockedStation.scriptInfo["oolite-barred-equipment"])
	{
		if (player.ship.dockedStation.scriptInfo["oolite-barred-equipment"].indexOf(equipment) != -1)
		{
			return false;
		};
	};

	// OXP hook to allow ships to forbid specific "available to all" equipment
	if(ship.scriptInfo && ship.scriptInfo["oolite-barred-equipment"] && ship.scriptInfo["oolite-barred-equipment"].indexOf(equipment) != -1)
	{
		return false;
	};
	
	// for compatibility with Laser Mount Switching System (LMSS)
	var lmss = worldScripts.LMSS_Core;

	if(lmss && lmss._switching == true) 
	{
		return true;
	};
	
	// Cannon and Accelerator only fit in larger ships like a Cobra Mark III
	if(ship.mass < 200000 && (equipment == "EQ_WEAPON_CANNON_THARGOID" || equipment == "EQ_WEAPON_THARGOID_PLASMA_ACCELERATOR"))
	{
		shipMass = 1;
		return false;
	};
	
	// awarded equipment to NPC's on setup or added by JS
	if((context == "npc" || context == "scripted") && shipMass == 0)
	{
		return true;
	};

	if(system && !system.sun.hasGoneNova && !system.sun.isGoingNova)
	{
		// shipyards at stations
		if((context == "newShip" || context == "purchase") && player.ship.dockedStation && shipMass == 0)
		{
			// TechLevel 14+ stations always have them on stock
			if(player.ship.dockedStation.equivalentTechLevel > 13)
			{
				return true;
			};
			
			// there is a chance in anarchies, feudals and multi-gov systems at locations with a TechLevel 7+
			if(system.info.government <= 2 && player.ship.dockedStation.equivalentTechLevel > 6 && dice > 75)
			{
				return true;
			};

			// independent and sleazy places with a TechLevel 7+ offer them as well once in a while
			if(system.info.government > 2 && player.ship.dockedStation.allegiance != "galcop"
			   && player.ship.dockedStation.equivalentTechLevel > 6 && dice > 65)
			{
				return true;
			};
		};
	};
	
	// otherwise prohibited
	return false;
};	


